% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Backward.R
\name{Backward}
\alias{Backward}
\title{Backward Algorithm for HMM}
\usage{
Backward(Y, T_mat, O, scale)
}
\arguments{
\item{Y}{Integer vector of observations (values in 1:N)}

\item{T_mat}{Transition matrix (K x K), \code{T_mat[i,j] = P(X_t=j | X_{t-1}=i)}}

\item{O}{Emission matrix (K x N), \code{O[i,j] = P(Y_t=j | X_t=i)}}

\item{scale}{Scaling factors from \code{\link{Forward}} (length T_len)}
}
\value{
Matrix (K x T_len) of scaled backward probabilities
}
\description{
Computes backward probabilities \eqn{\beta_t(i) = P(Y_{t+1}, \ldots, Y_T | X_t = i)}
using the same scaling factors from the Forward algorithm.
}
